@@ -48,16 +48,18 @@
         out of global and into something per-open-dbg.
 */
 
+#include <config.h>
+
+#include <stdlib.h> /* calloc() free() */
+
+#include "dwarf.h"
+#include "libdwarf.h"
+#include "libdwarf_private.h"
 #include "dd_globals.h"
-#ifdef HAVE_STDINT_H
-#include <stdint.h>
-#endif /* HAVE_STDINT_H */
 #include "dd_tsearchbal.h"
 #include "dd_macrocheck.h"
 #include "dd_esb.h"
 
-#define TRUE 1
-#define FALSE 0
 /*  WARNING: the tree walk functions will, if presented **tree
     when *tree is wanted, simply find nothing. No error,
     just bad results. So when a walk produces nothing
@@ -88,10 +90,10 @@ static struct Macrocheck_Map_Entry_s * macrocheck_map_insert(
 static void macrocheck_map_destroy(void *map);
 static Dwarf_Unsigned macro_count_recs(void **base);
 
-#ifdef SELFTEST
+#ifdef TESTING
 int failcount = 0;
 struct glflags_s glflags;
-#endif /* SELFTEST */
+#endif /* TESTING */
 
 static struct Macrocheck_Map_Entry_s *
 macrocheck_map_create_entry(Dwarf_Unsigned offset,
@@ -343,7 +345,7 @@ qsort_compare(const void *lin, const void *rin)
 static void
 warnprimeandsecond(struct Macrocheck_Map_Entry_s *r)
 {
-#ifdef SELFTEST
+#ifdef TESTING
         ++failcount;
 #endif
     glflags.gf_count_major_errors++;
@@ -394,7 +396,7 @@ print_macrocheck_statistics(const char *name,void **tsbase,
     mac_as_array = (struct Macrocheck_Map_Entry_s **)calloc(count,
         sizeof(struct Macrocheck_Map_Entry_s *));
     if (!mac_as_array) {
-#ifdef SELFTEST
+#ifdef TESTING
         ++failcount;
 #endif
         glflags.gf_count_major_errors++;
@@ -430,7 +432,7 @@ print_macrocheck_statistics(const char *name,void **tsbase,
             highest = end;
         }
         if (r->mp_refcount_primary > 1) {
-#ifdef SELFTEST
+#ifdef TESTING
             ++failcount;
 #endif
             glflags.gf_count_major_errors++;
@@ -471,7 +473,7 @@ print_macrocheck_statistics(const char *name,void **tsbase,
             internalgap += (r->mp_key - lastend);
         } else if (r->mp_key < lastend) {
             /* crazy overlap */
-#ifdef SELFTEST
+#ifdef TESTING
             ++failcount;
 #endif
             glflags.gf_count_major_errors++;
@@ -500,7 +502,7 @@ print_macrocheck_statistics(const char *name,void **tsbase,
     wholegap = mac_as_array[0]->mp_key + internalgap;
     if (lastend > section_size) {
         /* Something seriously wrong */
-#ifdef SELFTEST
+#ifdef TESTING
         ++failcount;
 #endif
         printf(" ERROR: For offset 0x%" DW_PR_XZEROS DW_PR_DUx
@@ -620,92 +622,3 @@ macro_import_stack_cleanout(void)
 {
     macro_import_stack_next_to_use = 0;
 }
-
-#ifdef SELFTEST
-int
-main()
-{
-    void * base = 0;
-    Dwarf_Unsigned count = 0;
-    int basefailcount = 0;
-    Dwarf_Error err = 0;
-    int isdwarf5=FALSE;
-
-    /* Test 1 */
-    add_macro_import(&base,TRUE,200,0,0);
-    count = macro_count_recs(&base);
-    if (count != 1) {
-        printf("FAIL: expect count 1, got %" DW_PR_DUu "\n",count);
-        ++failcount;
-    }
-    print_macrocheck_statistics("test1",&base,isdwarf5,2000,&err);
-
-    /* Test two */
-    add_macro_area_len(&base,200,100);
-    add_macro_import(&base,FALSE,350,0,0);
-    add_macro_area_len(&base,350,100);
-    count = macro_count_recs(&base);
-    if (count != 2) {
-        printf("FAIL: expect count 2, got %" DW_PR_DUu "\n",count);
-        ++failcount;
-    }
-    print_macrocheck_statistics("test 2",&base,isdwarf5,2000,&err);
-    clear_macrocheck_statistics(&base);
-
-    /* Test three */
-    basefailcount = failcount;
-    add_macro_import(&base,TRUE,0,0,0);
-    add_macro_area_len(&base,0,1000);
-    add_macro_import(&base,FALSE,2000,0,0);
-    add_macro_area_len(&base,2000,100);
-    mark_macro_offset_printed(&base,2000);
-    add_macro_import(&base,FALSE,1000,0,0);
-    add_macro_area_len(&base,1000,900);
-    add_macro_import(&base,FALSE,1000,0,0);
-    add_macro_area_len(&base,1000,900);
-    count = macro_count_recs(&base);
-    if (count != 3) {
-        printf("FAIL: expect count 3, got %" DW_PR_DUu "\n",count);
-        ++failcount;
-    }
-    printf("\n  Expect an ERROR about overlap with "
-        "the end of section\n");
-    print_macrocheck_statistics("test 3",&base,isdwarf5,2000,&err);
-    clear_macrocheck_statistics(&base);
-    if ((basefailcount+1) != failcount) {
-        printf("FAIL: Found no error in test 3 checking!\n");
-        ++failcount;
-    } else {
-        failcount = basefailcount;
-    }
-
-    /* Test Four */
-    basefailcount = failcount;
-    add_macro_import(&base,TRUE,50,0,0);
-    add_macro_import(&base,TRUE,50,0,0);
-    add_macro_area_len(&base,50,50);
-    add_macro_import(&base,FALSE,200,0,0);
-    add_macro_import(&base,FALSE,50,0,0);
-    add_macro_import(&base,FALSE,60,0,0);
-    add_macro_area_len(&base,60,10);
-    printf( "\n  Expect an ERROR about offset 50 having "
-        "2 primaries\n");
-    printf( "  and Expect an ERROR about offset 50 having 2\n"
-        "  primaries"
-        " and a secondary\n");
-    printf( "  and Expect an ERROR about crazy overlap 60\n\n");
-    print_macrocheck_statistics("test 4",&base,isdwarf5,2000,&err);
-    clear_macrocheck_statistics(&base);
-    if ((basefailcount + 3) != failcount) {
-        printf("FAIL: Found wrong errors in test 4 checking!\n");
-    } else {
-        failcount = basefailcount;
-    }
-    if (failcount > 0) {
-        printf("FAIL macrocheck selftest\n");
-        exit(1);
-    }
-    printf("PASS macrocheck selftest\n");
-    return 0;
-}
-#endif /* SELFTEST */
