@@ -33,24 +33,33 @@ Portions Copyright 2012 SN Systems Ltd. All rights reserved.
    Boston, MA 02110-1301, USA.
    SGI has moved from the Crittenden Lane address.
 */
-#include "dd_globals.h"
-/* for 'open' */
-#ifdef SYS_TYPES_H
-#include <sys/types.h>
-#endif /* SYS_TYPES_H */
-#ifdef SYS_STAT_H
-#include <sys/stat.h>
-#endif /* SYS_STAT_H */
-#include <stdlib.h> /* for exit() */
-#include <string.h> /* for strrchr */
-#include <fcntl.h>
-#include <limits.h>
+
+#include <config.h>
+
+#include <stddef.h> /* NULL */
+#include <stdio.h>  /* stdout stderr fprintf() printf() sprintf() */
+#include <stdlib.h> /* exit() free() malloc() qsort() realloc() */
+#include <string.h> /* memset() strcmp() stricmp()
+    strlen() strrchr() strstr() */
+
+/* Windows specific header files */
 #ifdef _WIN32
-#include <io.h> /* for dup2() */
+#ifdef HAVE_STDAFX_H
+#include "stdafx.h"
+#endif /* HAVE_STDAFX_H */
+#include <io.h> /* close() dup2() */
 #elif defined HAVE_UNISTD_H
-#include <unistd.h> /* for dup2() */
+#include <unistd.h> /* close() dup2() */
 #endif /* _WIN32 */
 
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h> /* O_RDONLY open() */
+#endif /* HAVE_FCNTL_H */
+
+#include "dwarf.h"
+#include "libdwarf.h"
+#include "libdwarf_private.h"
+#include "dd_globals.h"
 #include "dd_makename.h"
 #include "dd_macrocheck.h"
 #include "dd_dwconf.h"
@@ -1624,6 +1633,7 @@ should_skip_this_cu(Dwarf_Debug dbg, Dwarf_Bool*should_skip,
                 if (stricmp(lcun, p)) {
                     /* skip this cu. */
                     dwarf_dealloc_attribute(attrib);
+                    attrib = 0;
                     *should_skip = TRUE;
                     return DW_DLV_OK;
                 }
@@ -1631,6 +1641,7 @@ should_skip_this_cu(Dwarf_Debug dbg, Dwarf_Bool*should_skip,
                 if (strcmp(lcun, p)) {
                     /* skip this cu. */
                     dwarf_dealloc_attribute(attrib);
+                    attrib = 0;
                     *should_skip = TRUE;
                     return DW_DLV_OK;
                 }
@@ -1641,6 +1652,7 @@ should_skip_this_cu(Dwarf_Debug dbg, Dwarf_Bool*should_skip,
                 int dwarf_names_print_on_error = 1;
 
                 dwarf_dealloc_attribute(attrib);
+                attrib = 0;
                 esb_constructor(&m);
                 esb_append(&m,"In determining if we should "
                     "skip this CU dwarf_formstring "
@@ -1658,6 +1670,7 @@ should_skip_this_cu(Dwarf_Debug dbg, Dwarf_Bool*should_skip,
             } else {
                 /* DW_DLV_NO_ENTRY on the string itself */
                 dwarf_dealloc_attribute(attrib);
+                attrib = 0;
                 *should_skip = FALSE;
                 return sres;
             }
@@ -1669,10 +1682,13 @@ should_skip_this_cu(Dwarf_Debug dbg, Dwarf_Bool*should_skip,
             " attempting to determine if this CU should"
             " be skipped.",
             fres, skperr);
+        DROP_ERROR_INSTANCE(dbg,fres,skperr);
+        fres = DW_DLV_NO_ENTRY;
     } else  {
         /* DW_DLV_NO_ENTRY, nothing to print */
     }
     dwarf_dealloc_attribute(attrib);
+    attrib = 0;
     *should_skip = FALSE;
     return fres;
 }
