@@ -33,6 +33,14 @@ Portions Copyright 2008-2020 David Anderson. All rights reserved.
     SGI has moved from the Crittenden Lane address.
 */
 
+#include <config.h>
+
+#include <stdlib.h> /* calloc() free() realloc() */
+#include <string.h> /* memset() */
+
+#include "dwarf.h"
+#include "libdwarf.h"
+#include "libdwarf_private.h"
 #include "dd_globals.h"
 #include "dd_naming.h"
 #include "dd_sanitized.h"
@@ -41,9 +49,6 @@ Portions Copyright 2008-2020 David Anderson. All rights reserved.
 
 #include "print_sections.h"
 
-#define TRUE  1
-#define FALSE 0
-
 /* The following relevent for one specific Linker. */
 #define SNLINKER_MAX_ATTRIB_COUNT  16
 /*  a warning limit which is arbitrary but
@@ -717,10 +722,10 @@ get_abbrev_array_info(Dwarf_Debug dbg, Dwarf_Unsigned offset_in)
 {
     Dwarf_Unsigned offset = offset_in;
     if (glflags.gf_check_abbreviations) {
-        Dwarf_Unsigned length = 0;
+        Dwarf_Unsigned length           = 0;
         Dwarf_Unsigned last_abbrev_code = 0;
-        Dwarf_Bool bMore = TRUE;
-        Dwarf_Unsigned CU_abbrev_count = 0;
+        Dwarf_Bool bMore                = TRUE;
+        Dwarf_Unsigned CU_abbrev_count  = 0;
 
         if (abbrev_array == NULL) {
             /* Allocate initial abbreviation array info */
@@ -734,11 +739,11 @@ get_abbrev_array_info(Dwarf_Debug dbg, Dwarf_Unsigned offset_in)
         }
 
         while (bMore) {
-            Dwarf_Abbrev ab = 0;
-            int abres = DW_DLV_OK;
+            Dwarf_Abbrev ab            = 0;
+            int abres                  = DW_DLV_OK;
             Dwarf_Unsigned abbrev_entry_count = 0;
-            Dwarf_Unsigned abbrev_code;
-            Dwarf_Error aberr = 0;
+            Dwarf_Unsigned abbrev_code = 0;
+            Dwarf_Error aberr          = 0;
 
             abres = dwarf_get_abbrev(dbg, offset, &ab,
                 &length, &abbrev_entry_count, &aberr);
@@ -825,6 +830,7 @@ validate_abbrev_code(Dwarf_Debug dbg UNUSEDARG,
 {
     char buf[128];
 
+    buf[0] = 0;
     DWARF_CHECK_COUNT(abbreviations_result,1);
     if (abbrev_code && abbrev_code >= abbrev_array_size) {
         struct esb_s ar;
@@ -859,7 +865,7 @@ validate_abbrev_code(Dwarf_Debug dbg UNUSEDARG,
                     "Number of attributes exceeds sanity check");
                 esb_destructor(&ar);
             } else {
-                /*  These apply only to one compiliation environment,
+                /*  These apply only to one compilation environment,
                     and are not generally applicable.  */
                 struct esb_s ar;
                 esb_constructor_fixed(&ar,buf,sizeof(buf));
