@@ -28,6 +28,13 @@ Portions Copyright 2008-2020 David Anderson. All rights reserved.
 
 */
 
+#include <config.h>
+
+#include <string.h> /* strlen() */
+
+#include "dwarf.h"
+#include "libdwarf.h"
+#include "libdwarf_private.h"
 #include "dd_globals.h"
 #include "dd_naming.h"
 #include "dd_esb.h"
@@ -265,7 +272,7 @@ print_pubnames(Dwarf_Debug dbg,Dwarf_Error *err)
     }
     if (glflags.verbose) {
         /* For best testing! */
-        res = dwarf_return_empty_pubnames(dbg,1,err);
+        res = dwarf_return_empty_pubnames(dbg,1);
         if (res != DW_DLV_OK) {
             simple_err_return_msg_either_action(res,
                 "ERROR: Erroneous "
@@ -308,7 +315,7 @@ print_pubnames(Dwarf_Debug dbg,Dwarf_Error *err)
         globbuf,count,err);
     esb_destructor(&sanitname);
     dwarf_globals_dealloc(dbg,globbuf,count);
-    dwarf_return_empty_pubnames(dbg,0,err);
+    dwarf_return_empty_pubnames(dbg,0);
     return res;
 }
 
